#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_LIBSM
#undef PACKAGE_LOCALE_DIR
#undef PACKAGE_DATA_DIR
#undef PACKAGE_SOURCE_DIR
#undef PIXMAPS_DIR
#undef SCRIPTS_DIR
#undef ETSPECS_DIR
#undef INTERFACES_DIR
#undef HAVE_CRYPT_H
#undef FRONTEND_DIR
#undef DESKTOP_DATA_DIR
